@@ -382,9 +382,9 @@ class Interval(IntervalLike):
         elif other.right > self.right:
             # other is a superset of self
             return other
-        else:  # noqa
+        else:
             # This should never happen
-            raise NotImplementedError("Can't merge {} and {}".format(self, other))
+            raise NotImplementedError(f"Can't merge {self} and {other}")
 
     def intersection(self, other):
         """
@@ -402,6 +402,9 @@ class Interval(IntervalLike):
         if self.is_empty() or other.is_empty():
             return Interval(None, None)
 
+        if isinstance(other, IntervalUnion):
+            return other.intersection(self)
+
         # Standardize - after this step, the other.left is left of self.left
         if other.left > self.left:
             other, self = self, other
@@ -418,10 +421,9 @@ class Interval(IntervalLike):
         elif other.right > self.right:
             # other is a superset of self
             return self
-        else:  # noqa
+        else:
             # This should never happen
-            error_string = "Can't intersect {} and {}".format(self, other)
-            raise NotImplementedError(error_string)
+            raise NotImplementedError(f"Can't intersect {self} and {other}")
 
     def __repr__(self):
         """Get an unambiguous representation."""
