@@ -109,7 +109,7 @@ class Trie(AbstractTrie):
     def __len__(self):
         return self._length
 
-    def __contains__(self, element: str) -> bool:
+    def __contains__(self, element) -> bool:
         found_prefix, subtrie = self.get_subtrie(element)
         return subtrie.is_word and found_prefix + subtrie._value == element
 
@@ -119,8 +119,6 @@ class Trie(AbstractTrie):
             yield found_prefix + word
 
     def get_subtrie(self, prefix) -> Tuple[str, TrieNode]:
-        if self._root is None:
-            return ("", EMPTY_NODE)
         return self._root.get_subtrie(prefix)
 
     def __iter__(self):
