@@ -18,7 +18,9 @@ class TrieNode:
         self.count = count
         self.is_frozen = freeze
 
-    def get_subtrie(self, search_prefix: str, current_trie_node_prefix: str = ""):
+    def get_subtrie(
+        self, search_prefix: str, current_trie_node_prefix: str = ""
+    ) -> Tuple[str, "TrieNode"]:
         """
         Get the TrieNodes which represents the given prefix.
 
@@ -151,7 +153,7 @@ class Trie(AbstractTrie):
     def __len__(self):
         return self._length
 
-    def __contains__(self, element: str) -> bool:
+    def __contains__(self, element) -> bool:
         found_prefix, subtrie = self.get_subtrie(element)
         return subtrie.is_word and found_prefix + subtrie._value == element
 
